@@ -59,8 +59,11 @@ class Magma(object):
         @param creator: An identifier for the creator of the Magma file. 
         @type creator: String
         
-        @param data: Raw file data as read from a Magma file. 
-        @type data: String
+        @param yaml_data: Raw file data as read from a Magma file. 
+        @type yaml_data: String
+        
+        @param data: A native Python dict with the data. 
+        @type data: Dict
         
         """
         #: All data inside the Magma list
